@@ -6,7 +6,7 @@ set -e
 PACKAGE=stylish-haskell
 echo Downloading and running $PACKAGE...
 
-RELEASES=$(curl --silent https://github.com/jaspervdj/$PACKAGE/releases)
+RELEASES=$(curl --silent https://github.com/haskell/$PACKAGE/releases)
 URL=https://github.com/$(echo $RELEASES | grep -o '\"[^\"]*-linux-x86_64\.tar\.gz\"' | sed s/\"//g | head -n1)
 VERSION=$(echo $URL | sed -e 's/.*-\(v[\.0-9]\+-linux-x86_64\)\.tar\.gz/\1/')
 TEMP=$(mktemp --directory .$PACKAGE-XXXXX)
