@@ -1,5 +1,6 @@
+{-# LANGUAGE OverloadedStrings #-}
 --------------------------------------------------------------------------------
-{-# LANGUAGE OverloadedLists #-}
+{-# LANGUAGE OverloadedLists   #-}
 module Language.Haskell.Stylish.Step.Imports.Tests
     ( tests
     ) where
@@ -8,7 +9,7 @@ module Language.Haskell.Stylish.Step.Imports.Tests
 --------------------------------------------------------------------------------
 import           Test.Framework                        (Test, testGroup)
 import           Test.Framework.Providers.HUnit        (testCase)
-import           Test.HUnit                            (Assertion, (@=?))
+import           Test.HUnit                            (Assertion)
 
 
 --------------------------------------------------------------------------------
@@ -57,11 +58,27 @@ tests = testGroup "Language.Haskell.Stylish.Step.Imports.Tests"
     , testCase "case 23b" case23b
     , testCase "case 24" case24
     , testCase "case 25" case25
-    , testCase "case 26 (issue 185)" case26
+    , testCase "case 26 (issue #185)" case26
     , testCase "case 27" case27
     , testCase "case 28" case28
     , testCase "case 29" case29
     , testCase "case 30" case30
+    , testCase "case 31" case31
+    , testCase "case 32" case32
+    , testCase "case 33" case33
+    , testCase "case 34" case34
+    , testCase "case 35" case35
+    , testCase "case 36" case36
+    , testCase "case 37" case37
+    , testCase "case 38" case38
+    , testCase "case 39" case39
+    , testCase "case 40" case40
+    , testCase "case 41" case41
+    , testCase "case 42" case42
+    , testCase "case 43" case43
+    , testCase "case 44a" case44a
+    , testCase "case 44b" case44b
+    , testCase "case 44c" case44c
     ]
 
 
@@ -190,7 +207,7 @@ case07 = assertSnippet (step (Just 80) $ fromImportAlign File)
 case08 :: Assertion
 case08 =
   let
-    options = Options Global WithAlias True Inline Inherit (LPConstant 4) True False
+    options = defaultOptions { listAlign = WithAlias }
   in
     assertSnippet (step (Just 80) options) input
     [ "module Herp where"
@@ -214,7 +231,7 @@ case08 =
 case08b :: Assertion
 case08b =
   let
-    options = Options Global WithModuleName True Inline Inherit (LPConstant 4) True False
+    options = defaultOptions { listAlign = WithModuleName }
   in
     assertSnippet (step (Just 80) options) input
     ["module Herp where"
@@ -237,7 +254,7 @@ case08b =
 case09 :: Assertion
 case09 =
   let
-    options = Options Global WithAlias True Multiline Inherit (LPConstant 4) True False
+    options = defaultOptions { listAlign = WithAlias, longListAlign = Multiline }
   in
     assertSnippet (step (Just 80) options) input
     [ "module Herp where"
@@ -272,7 +289,11 @@ case09 =
 case10 :: Assertion
 case10 =
   let
-    options = Options Group WithAlias True Multiline Inherit (LPConstant 4) True False
+    options = defaultOptions
+      { importAlign   = Group
+      , listAlign     = WithAlias
+      , longListAlign = Multiline
+      }
   in
     assertSnippet (step (Just 40) options) input
     [ "module Herp where"
@@ -313,7 +334,7 @@ case10 =
 case11 :: Assertion
 case11 =
   let
-    options = Options Group NewLine True Inline Inherit (LPConstant 4) True False
+    options = defaultOptions { importAlign = Group, listAlign = NewLine }
   in
     assertSnippet (step (Just 80) options) input
     [ "module Herp where"
@@ -340,7 +361,7 @@ case11 =
 case11b :: Assertion
 case11b =
   let
-    options = Options Group WithModuleName True Inline Inherit (LPConstant 4) True False
+    options = defaultOptions { importAlign = Group, listAlign = WithModuleName }
   in
     assertSnippet (step (Just 80) options) input
     [ "module Herp where"
@@ -363,7 +384,11 @@ case11b =
 case12 :: Assertion
 case12 =
   let
-    options = Options Group NewLine True Inline Inherit (LPConstant 2) True False
+    options = defaultOptions
+      { importAlign = Group
+      , listAlign   = NewLine
+      , listPadding = LPConstant 2
+      }
   in
     assertSnippet (step (Just 80) options)
     [ "import Data.List (map)"
@@ -377,7 +402,11 @@ case12 =
 case12b :: Assertion
 case12b =
   let
-    options = Options Group WithModuleName True Inline Inherit (LPConstant 2) True False
+    options = defaultOptions
+      { importAlign = Group
+      , listAlign   = WithModuleName
+      , listPadding = LPConstant 2
+      }
   in
     assertSnippet (step (Just 80) options)
     ["import Data.List (map)"]
@@ -388,7 +417,11 @@ case12b =
 case13 :: Assertion
 case13 =
   let
-    options = Options None WithAlias True InlineWithBreak Inherit (LPConstant 4) True False
+    options = defaultOptions
+      { importAlign   = None
+      , listAlign     = WithAlias
+      , longListAlign = InlineWithBreak
+      }
   in
     assertSnippet (step (Just 80) options)
     [ "import qualified Data.List as List (concat, foldl, foldr, head, init,"
@@ -402,7 +435,11 @@ case13 =
 case13b :: Assertion
 case13b =
   let
-    options = Options None WithModuleName True InlineWithBreak Inherit (LPConstant 4) True False
+    options = defaultOptions
+      { importAlign   = None
+      , listAlign     = WithModuleName
+      , longListAlign = InlineWithBreak
+      }
   in
     assertSnippet (step (Just 80) options)
     [ "import qualified Data.List as List (concat, foldl, foldr, head, init,"
@@ -418,7 +455,12 @@ case13b =
 case14 :: Assertion
 case14 =
   let
-    options = Options None WithAlias True InlineWithBreak Inherit (LPConstant 10) True False
+    options = defaultOptions
+      { importAlign   = None
+      , listAlign     = WithAlias
+      , longListAlign = InlineWithBreak
+      , listPadding   = LPConstant 10
+      }
   in
     assertSnippet (step (Just 80) options)
     [ "import qualified Data.List as List (concat, map, null, reverse, tail, (++))"
@@ -431,7 +473,7 @@ case14 =
 case15 :: Assertion
 case15 =
   let
-    options = Options None AfterAlias True Multiline Inherit (LPConstant 4) True False
+    options = defaultOptions { importAlign = None, longListAlign = Multiline }
   in
     assertSnippet (step (Just 80) options)
     [ "import Data.Acid (AcidState)"
@@ -456,7 +498,11 @@ case15 =
 case16 :: Assertion
 case16 =
   let
-    options = Options None AfterAlias True Multiline Inherit (LPConstant 4) False False
+    options = defaultOptions
+      { importAlign   = None
+      , longListAlign = Multiline
+      , separateLists = False
+      }
   in
     assertSnippet (step (Just 80) options)
     [ "import Data.Acid (AcidState)"
@@ -479,7 +525,7 @@ case16 =
 case17 :: Assertion
 case17 =
   let
-    options = Options None AfterAlias True Multiline Inherit (LPConstant 4) True False
+    options = defaultOptions { importAlign = None, longListAlign = Multiline }
   in
     assertSnippet (step (Just 80) options)
     [ "import Control.Applicative (Applicative ((<*>),pure))"
@@ -496,7 +542,7 @@ case17 =
 case18 :: Assertion
 case18 =
   let
-    options = Options None AfterAlias True InlineToMultiline Inherit (LPConstant 4) True False
+    options = defaultOptions { importAlign = None, longListAlign = InlineToMultiline }
   in
     assertSnippet (step (Just 40) options)
     [ "import Data.Foo as Foo (Bar, Baz, Foo)"
@@ -523,7 +569,12 @@ case18 =
 case19 :: Assertion
 case19 =
   let
-    options = Options Global NewLine True InlineWithBreak RightAfter (LPConstant 17) True False
+    options = defaultOptions
+      { listAlign      = NewLine
+      , longListAlign  = InlineWithBreak
+      , emptyListAlign = RightAfter
+      , listPadding    = LPConstant 17
+      }
   in
     assertSnippet (step (Just 40) options) case19input
        ----------------------------------------
@@ -539,7 +590,13 @@ case19 =
 case19b :: Assertion
 case19b =
   let
-    options = Options File NewLine True InlineWithBreak RightAfter (LPConstant 17) True False
+    options = defaultOptions
+      { importAlign    = File
+      , listAlign      = NewLine
+      , longListAlign  = InlineWithBreak
+      , emptyListAlign = RightAfter
+      , listPadding    = LPConstant 17
+      }
   in
     assertSnippet (step (Just 40) options) case19input
        ----------------------------------------
@@ -554,7 +611,13 @@ case19b =
 case19c :: Assertion
 case19c =
   let
-    options = Options File NewLine True InlineWithBreak RightAfter LPModuleName True False
+    options = defaultOptions
+      { importAlign    = File
+      , listAlign      = NewLine
+      , longListAlign  = InlineWithBreak
+      , emptyListAlign = RightAfter
+      , listPadding    = LPModuleName
+      }
   in
     assertSnippet (step (Just 40) options) case19input
        ----------------------------------------
@@ -569,7 +632,12 @@ case19c =
 case19d :: Assertion
 case19d =
   let
-    options = Options Global NewLine True InlineWithBreak RightAfter LPModuleName True False
+    options = defaultOptions
+      { listAlign      = NewLine
+      , longListAlign  = InlineWithBreak
+      , emptyListAlign = RightAfter
+      , listPadding    = LPModuleName
+      }
   in
     assertSnippet (step (Just 40) options) case19input
        ----------------------------------------
@@ -593,21 +661,17 @@ case19input = Snippet
 
 --------------------------------------------------------------------------------
 case20 :: Assertion
-case20 = expected
-    @=? testSnippet (step (Just 80) defaultOptions) input'
-  where
-    expected = Snippet
-        [ "import {-# SOURCE #-}           Data.ByteString as BS"
-        , "import                qualified Data.Map        as Map"
-        , "import                          Data.Set        (empty)"
-        , "import {-# SOURCE #-} qualified Data.Text       as T"
-        ]
-    input' = Snippet
-        [ "import {-# SOURCE #-}    Data.ByteString as BS"
-        , "import {-# SOURCE #-} qualified Data.Text as T"
-        , "import qualified   Data.Map as Map"
-        , "import Data.Set (empty)"
-        ]
+case20 = assertSnippet (step (Just 80) defaultOptions)
+    [ "import {-# SOURCE #-}    Data.ByteString as BS"
+    , "import {-# SOURCE #-} qualified Data.Text as T"
+    , "import qualified   Data.Map as Map"
+    , "import Data.Set (empty)"
+    ]
+    [ "import {-# SOURCE #-}           Data.ByteString as BS"
+    , "import                qualified Data.Map        as Map"
+    , "import                          Data.Set        (empty)"
+    , "import {-# SOURCE #-} qualified Data.Text       as T"
+    ]
 
 
 --------------------------------------------------------------------------------
@@ -665,7 +729,11 @@ case22 = assertSnippet (step (Just 80) defaultOptions)
 case23 :: Assertion
 case23 =
   let
-    options = Options None AfterAlias False Inline Inherit (LPConstant 4) True True
+    options = defaultOptions
+      { importAlign    = None
+      , padModuleNames = False
+      , spaceSurround  = True
+      }
   in
     assertSnippet (step (Just 40) options)
     [ "import Data.Acid (AcidState)"
@@ -690,7 +758,12 @@ case23 =
 case23b :: Assertion
 case23b =
   let
-    options = Options None WithModuleName False Inline Inherit (LPConstant 4) True True
+    options = defaultOptions
+      { importAlign    = None
+      , listAlign      = WithModuleName
+      , padModuleNames = False
+      , spaceSurround  = True
+      }
   in
     assertSnippet (step (Just 40) options)
     [ "import Data.Acid (AcidState)"
@@ -716,7 +789,12 @@ case23b =
 case24 :: Assertion
 case24 =
   let
-    options = Options None AfterAlias False InlineWithBreak Inherit (LPConstant 4) True True
+    options = defaultOptions
+      { importAlign    = None
+      , padModuleNames = False
+      , longListAlign  = InlineWithBreak
+      , spaceSurround  = True
+      }
   in
     assertSnippet (step (Just 40) options)
     [ "import Data.Acid (AcidState)"
@@ -740,7 +818,12 @@ case24 =
 case25 :: Assertion
 case25 =
   let
-    options = Options Group AfterAlias False Multiline Inherit (LPConstant 4) False False
+    options = defaultOptions
+      { importAlign    = Group
+      , padModuleNames = False
+      , longListAlign  = Multiline
+      , separateLists  = False
+      }
   in
     assertSnippet (step (Just 80) options)
     [ "import Data.Acid (AcidState)"
@@ -807,7 +890,7 @@ case28 = assertSnippet (step (Just 80) $ fromImportAlign Global)
     , "import Data.Set (empty, nub)"
     ]
     [ "import           Control.Monad"
-    ,  "import qualified Data.Aeson         as JSON"
+    , "import qualified Data.Aeson         as JSON"
     , "import           Data.Default.Class (Default (def))"
     , ""
     , "import           Data.Maybe         (Maybe (Just, Nothing))"
@@ -842,3 +925,369 @@ case30 :: Assertion
 case30 = assertSnippet (step Nothing defaultOptions {separateLists = False})
     ["import           Data.Monoid (Monoid (..))"]
     ["import           Data.Monoid (Monoid(..))"]
+
+--------------------------------------------------------------------------------
+case31 :: Assertion
+case31 = assertSnippet (step Nothing defaultOptions {postQualified = True})
+    ["import           Data.Monoid (Monoid (..))"]
+    ["import Data.Monoid (Monoid (..))"]
+
+--------------------------------------------------------------------------------
+case32 :: Assertion
+case32 = assertSnippet (step Nothing defaultOptions {postQualified = True})
+    ["import qualified Data.Monoid as M"]
+    ["import Data.Monoid qualified as M"]
+
+--------------------------------------------------------------------------------
+case33 :: Assertion
+case33 = assertSnippet (step Nothing defaultOptions {postQualified = True})
+    [ "import Data.Default.Class (Default(def))"
+    , "import qualified Data.Aeson as JSON"
+    , "import qualified Data.Aeson as JSON"
+    , "import Control.Monad"
+    , "import Control.Monad"
+    , ""
+    , "import Data.Maybe (Maybe   (Just, Nothing))"
+    , "import qualified Data.Maybe.Extra (Maybe(Just, Nothing))"
+    , ""
+    , "import Data.Foo (Foo (Foo,Bar), Goo(Goo))"
+    , "import Data.Foo (Foo (Foo,Bar))"
+    , "import Data.Set (empty, intersect)"
+    , "import Data.Set (empty, nub)"
+    ]
+    [ "import Control.Monad"
+    , "import Data.Aeson         qualified as JSON"
+    , "import Data.Default.Class (Default (def))"
+    , ""
+    , "import Data.Maybe         (Maybe (Just, Nothing))"
+    , "import Data.Maybe.Extra   qualified (Maybe (Just, Nothing))"
+    , ""
+    , "import Data.Foo           (Foo (Bar, Foo), Goo (Goo))"
+    , "import Data.Set           (empty, intersect, nub)"
+    ]
+
+--------------------------------------------------------------------------------
+case34 :: Assertion
+case34 = assertSnippet (step Nothing defaultOptions {postQualified = True})
+    [ "import qualified Data.Aeson as JSON (Value)"
+    ]
+    [ "import Data.Aeson qualified as JSON (Value)"
+    ]
+
+--------------------------------------------------------------------------------
+case35 :: Assertion
+case35 = assertSnippet (step Nothing defaultOptions {postQualified = True})
+    [ "import Data.Aeson qualified as JSON (Value)"
+    ]
+    [ "import Data.Aeson qualified as JSON (Value)"
+    ]
+
+--------------------------------------------------------------------------------
+case36 :: Assertion
+case36 = assertSnippet (step Nothing defaultOptions {postQualified = True})
+    [ "import qualified Data.Aeson as JSON (Value)"
+    , "import qualified Data.Aeson as JSON (encode, decode)"
+    ]
+    [ "import Data.Aeson qualified as JSON (Value, decode, encode)"
+    ]
+
+--------------------------------------------------------------------------------
+case37 :: Assertion
+case37 = assertSnippet (step Nothing defaultOptions {postQualified = True})
+    [ "import Data.Aeson qualified as JSON (Value)"
+    , "import Data.Aeson qualified as JSON (encode, decode)"
+    ]
+    [ "import Data.Aeson qualified as JSON (Value, decode, encode)"
+    ]
+
+--------------------------------------------------------------------------------
+case38 :: Assertion
+case38 = assertSnippet (step (Just 80) $ fromImportAlign File)
+    [ "import HSP"
+    , "import Happstack.Server"
+    ]
+    [ "import Happstack.Server"
+    , "import HSP"
+    ]
+
+--------------------------------------------------------------------------------
+case39 :: Assertion
+case39 = assertSnippet (step Nothing options)
+  [ "import Something.A"
+  , "import SomethingElse.A"
+  , "import SomeThing.B"
+  , "import SomeThingelse.B"
+  ]
+  [ "import           SomeThing.B"
+  , ""
+  , "import           SomeThingelse.B"
+  , ""
+  , "import           Something.A"
+  , ""
+  , "import           SomethingElse.A"
+  ]
+  where options = defaultOptions { groupImports = True }
+
+--------------------------------------------------------------------------------
+case40 :: Assertion
+case40 = assertSnippet (step Nothing options)
+    [ "import Data.Default.Class (Default(def))"
+    , "import qualified Data.Aeson as JSON"
+    , "import qualified Data.Aeson as JSON"
+    , "import Control.Monad"
+    , "import Control.Monad"
+    , ""
+    , "import Data.Maybe (Maybe   (Just, Nothing))"
+    , "import qualified Data.Maybe.Extra (Maybe(Just, Nothing))"
+    , ""
+    , "import Data.Foo (Foo (Foo,Bar), Goo(Goo))"
+    , "import Data.Foo (Foo (Foo,Bar))"
+    , "import Data.Set (empty, intersect)"
+    , "import Data.Set (empty, nub)"
+    ]
+    [ "import Control.Monad"
+    , ""
+    , "import Data.Aeson         qualified as JSON"
+    , "import Data.Default.Class (Default (def))"
+    , "import Data.Foo           (Foo (Bar, Foo), Goo (Goo))"
+    , "import Data.Maybe         (Maybe (Just, Nothing))"
+    , "import Data.Maybe.Extra   qualified (Maybe (Just, Nothing))"
+    , "import Data.Set           (empty, intersect, nub)"
+    ]
+  where options = defaultOptions { groupImports = True, postQualified = True }
+
+--------------------------------------------------------------------------------
+case41 :: Assertion
+case41 = assertSnippet (step Nothing options)
+    [ "import Data.Default.Class (Default(def))"
+    , "import qualified Data.Aeson as JSON"
+    , "import Control.Monad"
+    , "import Control.Monad"
+    , "import qualified Foo.Bar.Baz"
+    , ""
+    , "import Data.Set (empty, intersect)"
+    , "import Data.Maybe (Maybe   (Just, Nothing))"
+    , "import qualified Data.Maybe.Extra (Maybe(Just, Nothing))"
+    , ""
+    , "import qualified Data.Aeson as JSON"
+    , ""
+    , "import Data.Foo (Foo (Foo,Bar), Goo(Goo))"
+    , "import Data.Foo (Foo (Foo,Bar))"
+    , "import Data.Set (empty, nub)"
+    , "import Foo.Bar.Baz (Foo)"
+    ]
+    [ "import Control.Monad"
+    , ""
+    , "import qualified Data.Aeson         as JSON"
+    , "import           Data.Default.Class (Default (def))"
+    , "import           Data.Foo           (Foo (Bar, Foo), Goo (Goo))"
+    , "import           Data.Maybe         (Maybe (Just, Nothing))"
+    , "import qualified Data.Maybe.Extra   (Maybe (Just, Nothing))"
+    , "import           Data.Set           (empty, intersect, nub)"
+    , ""
+    , "import           Foo.Bar.Baz (Foo)"
+    , "import qualified Foo.Bar.Baz"
+    ]
+  where options = defaultOptions { groupImports = True, importAlign = Group }
+
+--------------------------------------------------------------------------------
+case42 :: Assertion
+case42 =
+    assertSnippet (step (Just 80) options)
+    [ "import Data.Acid (AcidState)"
+    , "import Data.Default.Class (Default (def))"
+    , "import Control.Monad"
+    , ""
+    , "import qualified Data.Acid as Acid (closeAcidState, createCheckpoint, openLocalStateFrom)"
+    , ""
+    , "import qualified Herp.Derp.Internal.Types.Foobar as Internal (foo, bar)"
+    ]
+    [ "import Control.Monad"
+    , ""
+    , "import Data.Acid (AcidState)"
+    , "import qualified Data.Acid as Acid"
+    , "    ( closeAcidState"
+    , "    , createCheckpoint"
+    , "    , openLocalStateFrom"
+    , "    )"
+    , "import Data.Default.Class (Default (def))"
+    , ""
+    , "import qualified Herp.Derp.Internal.Types.Foobar as Internal (bar, foo)"
+    ]
+  where options = defaultOptions
+          { groupImports  = True
+          , importAlign   = None
+          , longListAlign = Multiline
+          }
+
+--------------------------------------------------------------------------------
+case43 :: Assertion
+case43 =
+    assertSnippet (step (Just 80) options)
+    [ "import Project.Internal.Blah"
+    , "import Project.Something"
+    , "import Control.Monad"
+    , ""
+    , "import qualified Data.Acid as Acid (closeAcidState, createCheckpoint, openLocalStateFrom)"
+    , ""
+    , "import qualified Project.Internal.Blarg as Blarg"
+    , "import Control.Applicative"
+    , "import Data.Functor"
+    , "import Data.Acid (AcidState)"
+    , "import Project"
+    , ""
+    , "import Data.Map (Map)"
+    , "import qualified Data.Map as Map"
+    ]
+    [ "import Project.Internal.Blah"
+    , "import qualified Project.Internal.Blarg as Blarg"
+    , ""
+    , "import Project"
+    , "import Project.Something"
+    , ""
+    , "import Control.Applicative"
+    , "import Control.Monad"
+    , ""
+    , "import Data.Acid (AcidState)"
+    , "import qualified Data.Acid as Acid"
+    , "    ( closeAcidState"
+    , "    , createCheckpoint"
+    , "    , openLocalStateFrom"
+    , "    )"
+    , "import Data.Functor"
+    , "import Data.Map (Map)"
+    , "import qualified Data.Map as Map"
+    ]
+  where options = defaultOptions
+          { groupImports  = True
+          , groupRules    =
+              [ GroupRule
+                { match = unsafeParsePattern "Project\\.Internal"
+                , subGroup = Nothing
+                }
+              , GroupRule
+                { match = unsafeParsePattern "Project"
+                , subGroup = Nothing
+                }
+              , GroupRule
+                { match = unsafeParsePattern ".*"
+                , subGroup = Just $ unsafeParsePattern "^[^.]+"
+                }
+              ]
+          , importAlign   = None
+          , longListAlign = Multiline
+          }
+
+--------------------------------------------------------------------------------
+case44a :: Assertion
+case44a =
+    assertSnippet (step (Just 80) options)
+    [ "import Project"
+    , "import Control.Monad"
+    , ""
+    , "import qualified Data.Acid as Acid"
+    , "import Project.Something"
+    , "import Data.Default.Class (Default (def))"
+    , ""
+    , "import qualified Herp.Derp.Internal.Types.Foobar as Internal (foo, bar)"
+    , "import ProJect.WrongCapitalization"
+    ]
+    [ "import Project"
+    , "import Project.Something"
+    , ""
+    , "import Control.Monad"
+    , "import qualified Data.Acid as Acid"
+    , "import Data.Default.Class (Default (def))"
+    , "import qualified Herp.Derp.Internal.Types.Foobar as Internal (bar, foo)"
+    , "import ProJect.WrongCapitalization"
+    ]
+  where options = defaultOptions
+          { groupImports = True
+          , groupRules   = [ GroupRule
+                             { match = unsafeParsePattern "Project"
+                             , subGroup = Nothing
+                             }
+                           ]
+          , importAlign  = None
+          }
+
+--------------------------------------------------------------------------------
+case44b :: Assertion
+case44b =
+    assertSnippet (step (Just 80) options)
+    [ "import Project"
+    , "import Control.Monad"
+    , ""
+    , "import qualified Data.Acid as Acid"
+    , "import Project.Something"
+    , "import Data.Default.Class (Default (def))"
+    , ""
+    , "import qualified Herp.Derp.Internal.Types.Foobar as Internal (foo, bar)"
+    , "import ProJect.WrongCapitalization"
+    ]
+    [ "import Project"
+    , "import Project.Something"
+    , ""
+    , "import qualified Data.Acid as Acid"
+    , ""
+    , "import Data.Default.Class (Default (def))"
+    , ""
+    , "import qualified Herp.Derp.Internal.Types.Foobar as Internal (bar, foo)"
+    , ""
+    , "import Control.Monad"
+    , ""
+    , "import ProJect.WrongCapitalization"
+    ]
+  where options = defaultOptions
+          { groupImports = True
+          , groupRules   =
+              [ GroupRule
+                { match = unsafeParsePattern "Project"
+                , subGroup = Nothing
+                }
+              , GroupRule
+                { match    = unsafeParsePattern "[^.]+\\.[^.]+"
+                , subGroup = Just $ unsafeParsePattern "\\.[^.]+"
+                }
+              ]
+          , importAlign  = None
+          }
+
+
+--------------------------------------------------------------------------------
+case44c :: Assertion
+case44c =
+    assertSnippet (step (Just 80) options)
+    [ "import Project"
+    , "import Control.Monad"
+    , ""
+    , "import qualified Data.Acid as Acid"
+    , "import Project.Something"
+    , "import Data.Default.Class (Default (def))"
+    , ""
+    , "import qualified Herp.Derp.Internal.Types.Foobar as Internal (foo, bar)"
+    , "import ProJect.WrongCapitalization"
+    ]
+    [ "import Project"
+    , "import Project.Something"
+    , ""
+    , "import Control.Monad"
+    , "import qualified Data.Acid as Acid"
+    , "import Data.Default.Class (Default (def))"
+    , "import qualified Herp.Derp.Internal.Types.Foobar as Internal (bar, foo)"
+    , "import ProJect.WrongCapitalization"
+    ]
+  where options = defaultOptions
+          { groupImports = True
+          , groupRules   =
+              [ GroupRule
+                { match = unsafeParsePattern "Project"
+                , subGroup = Nothing
+                }
+              , GroupRule
+                { match = unsafeParsePattern "[^.]+\\.[^.]+"
+                , subGroup = Nothing
+                }
+              ]
+          , importAlign  = None
+          }
