@@ -24,6 +24,7 @@ tests = testGroup "Language.Haskell.Stylish.Step.SimpleSquash.Tests"
     , testCase "case 03" case03
     , testCase "case 04" case04
     , testCase "case 05" case05
+    , testCase "case 06 (issue #355)" case06
     ]
 
 
@@ -100,3 +101,13 @@ case05 = assertSnippet step
     [ "maybe y0 _ Nothing = y"
     , "maybe _  f (Just x) = f x"
     ]
+
+
+--------------------------------------------------------------------------------
+-- See <https://github.com/haskell/stylish-haskell/issues/355>
+case06 :: Assertion
+case06 = assertSnippet step
+    [ "main  =  (\\x ->  putStrLn x) \"Hello, World!\""
+    ]
+    [ "main = (\\x -> putStrLn x) \"Hello, World!\""
+    ]
