@@ -1,37 +1,53 @@
 {-# LANGUAGE BlockArguments #-}
 {-# LANGUAGE TypeFamilies   #-}
 module Language.Haskell.Stylish.Tests.Util
-    ( testStep
-    , testStep'
+    ( dumpAst
+    , dumpModule
     , Snippet (..)
-    , testSnippet
     , assertSnippet
     , withTestDirTree
-    , (@=??)
     ) where
 
 
 --------------------------------------------------------------------------------
-import           Control.Exception              (bracket, try)
-import           Control.Monad.Writer           (execWriter, tell)
-import           Data.List                      (intercalate)
-import           GHC.Exts                       (IsList (..))
-import           System.Directory               (createDirectory,
-                                                 getCurrentDirectory,
-                                                 getTemporaryDirectory,
-                                                 removeDirectoryRecursive,
-                                                 setCurrentDirectory)
-import           System.FilePath                ((</>))
-import           System.IO.Error                (isAlreadyExistsError)
-import           System.Random                  (randomIO)
-import           Test.HUnit                     (Assertion, assertFailure,
-                                                 (@=?))
-
+import           Control.Exception               (bracket, try)
+import           Data.Data                       (Data (..))
+import           GHC.Exts                        (IsList (..))
+import           GHC.Hs.Dump                     (BlankEpAnnotations (..),
+                                                  BlankSrcSpan (..),
+                                                  showAstData)
+import           System.Directory                (createDirectory,
+                                                  getCurrentDirectory,
+                                                  getTemporaryDirectory,
+                                                  removeDirectoryRecursive,
+                                                  setCurrentDirectory)
+import           System.FilePath                 ((</>))
+import           System.IO.Error                 (isAlreadyExistsError)
+import           System.Random                   (randomIO)
+import           Test.HUnit                      (Assertion, (@=?))
 
 --------------------------------------------------------------------------------
+import           Language.Haskell.Stylish.GHC    (showOutputable)
+import           Language.Haskell.Stylish.Module (Module)
 import           Language.Haskell.Stylish.Parse
 import           Language.Haskell.Stylish.Step
 
+--------------------------------------------------------------------------------
+-- | Takes a Haskell source as an argument and parse it into a Module.
+-- Extract function selects element from that Module record and returns
+-- its String representation.
+--
+-- This function should be used when trying to understand how particular
+-- Haskell code will be represented by ghc-parser's AST
+dumpAst :: Data a => (Module -> a) -> String -> String
+dumpAst extract str =
+  let Right(theModule) = parseModule [] Nothing str
+      ast              = extract theModule
+      sdoc             = showAstData BlankSrcSpan BlankEpAnnotations ast
+  in  showOutputable sdoc
+
+dumpModule :: String -> String
+dumpModule = dumpAst id
 
 --------------------------------------------------------------------------------
 testStep :: Step -> String -> String
@@ -44,11 +60,6 @@ testStep s str = case s of
     ls = lines str
 
 
---------------------------------------------------------------------------------
-testStep' :: Step -> Lines -> Lines
-testStep' s ls = lines $ testStep s (unlines ls)
-
-
 --------------------------------------------------------------------------------
 -- | 'Lines' that show as a normal string.
 newtype Snippet = Snippet {unSnippet :: Lines} deriving (Eq)
@@ -102,15 +113,3 @@ withTestDirTree action = bracket
         setCurrentDirectory current *>
         removeDirectoryRecursive temp)
     (\(_, temp) -> setCurrentDirectory temp *> action)
-
-(@=??) :: Lines -> Lines -> Assertion
-expected @=?? actual =
-  if expected == actual then pure ()
-  else assertFailure $ intercalate "\n" $ execWriter do
-    tell ["Expected:"]
-    printLines expected
-    tell ["Got:"]
-    printLines actual
-  where
-    printLines =
-      mapM_ \line -> tell ["  " <> line]
